@@ -9,6 +9,7 @@ from bs4 import BeautifulSoup
 
 from dwca.rows import CoreRow
 from dwca.utils import _EmbeddedCSV
+from dwca.descriptors import ArchiveDescriptor
 from dwca.exceptions import RowNotFound
 
 
@@ -42,9 +43,8 @@ class DwCAReader(object):
         self.close()
 
     def __init__(self, path):
-        """Open the file, reads all metadata and store it in self.meta
-        (BeautifulSoup obj.) Also already open the core file so we've
-        a file descriptor for further access.
+        """Open the file, reads all metadata and store it in self.metadata (BeautifulSoup obj.)
+        Also already open the core file so we've a file descriptor for further access.
 
         :param path: path to the Darwin Core Archive file to open.
         """
@@ -53,18 +53,14 @@ class DwCAReader(object):
 
         self._unzipped_folder_path = self._unzip()
         
-        #: A BeautifulSoup instance containing the archive descriptor (``meta.xml``)
-        self.descriptor = self._parse_metaxml_file()
+        #: An ArchiveDescriptor instance representing the archive descriptor (``meta.xml``)
+        self.descriptor = ArchiveDescriptor(self._read_additional_file('meta.xml'))
 
         # Load the (scientific) metadata file and store its representation in an attribute
         #:
         self.metadata = self._parse_metadata_file()
         #:
         self.source_metadata = None
-        #:
-        self.core_rowtype = self._get_core_type()
-        #:
-        self.extensions_rowtype = self._get_extensions_types()
 
         self._corefile = _EmbeddedCSV(self.descriptor.core,
                                       self._unzipped_folder_path)
@@ -134,16 +130,7 @@ class DwCAReader(object):
         """Load the archive (scientific) Metadata file, parse it with
         BeautifulSoup and return its content."""
 
-        # This method should be called only after descriptor attribute is set
-        # because the name/path to metadata file is stored in the "metadata"
-        # attribute of the "archive" tag
-        metadata_file = self._get_metadata_filename()
-        return self._parse_xml_included_file(metadata_file)
-
-    def _parse_metaxml_file(self):
-        """Load the meta.xml, parse it with BeautifulSoup and return its
-        content."""
-        return self._parse_xml_included_file('meta.xml')
+        return self._parse_xml_included_file(self.descriptor.metadata_filename)
 
     def _parse_xml_included_file(self, relative_path):
         """Load, parse with BeautifulSoup and returns XML file located
@@ -171,24 +158,9 @@ class DwCAReader(object):
     def _cleanup_temporary_folder(self):
         rmtree(self._unzipped_folder_path, False)
 
-    def _get_core_type(self):
-        return self.descriptor.core['rowType']
-
-    def _get_extensions_types(self):
-        return [e['rowType'] for e in self.descriptor.findAll('extension')]
-
     def core_contains_term(self, term_url):
         """Return True if the Core file of the archive contains the term_url term."""
-        return term_url in self.core_terms
-
-    @property
-    def core_terms(self):
-        """Return a Set containing all the Darwin Core terms appearing in Core file."""
-        term_names = [f['term'] for f in self.descriptor.core.findAll('field')]
-        return set(term_names)
-
-    def _get_metadata_filename(self):
-        return self.descriptor.archive['metadata']
+        return term_url in self.descriptor.core.terms
 
     def __iter__(self):
         self._corefile_pointer = 0
@@ -198,7 +170,8 @@ class DwCAReader(object):
         cl = self._corefile.get_row_by_index(self._corefile_pointer)
         if cl:
             self._corefile_pointer = self._corefile_pointer + 1
-            return CoreRow(cl, self.descriptor, self._unzipped_folder_path, self.source_metadata)
+            return CoreRow(cl, self.descriptor, self._unzipped_folder_path,
+                           self.source_metadata)
         else:
             raise StopIteration
 
